@@ -7,11 +7,13 @@ from .hydrogen_logging import hydrogen_setup_logger, cleanup_log_files
 from .message_bus import MessageBus
 from .run_job_using_callback import run_job_using_callback
 from .job_main import job_main
+from .run_job import start_async_job, run_remote_job
 from .directory_paths import (
     get_data_directory,
     get_domain_path,
     get_domain_database,
     get_domain_state,
+    update_domain_state,
     get_widget,
     get_hydrodata_directory,
     get_hydro_common_directory,
